@@ -2,7 +2,7 @@ package Net::Async::Redis::Cluster;
 
 use Full::Class qw(:v1), extends => qw(Net::Async::Redis::Commands);
 
-our $VERSION = '6.003'; # VERSION
+our $VERSION = '6.004'; # VERSION
 our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 =encoding utf8
@@ -45,6 +45,8 @@ Note that this adds some overhead to lookups, so you may be better served
 by options such as the L<https://github.com/twitter/twemproxy|twemproxy>
 proxy routing dæmon, or a service mesh such as L<https://istio.io/|istio>.
 
+See L</configure> for additional cluster configuration parameters.
+
 =cut
 
 use Future::Utils qw(fmap_void fmap_concat);
@@ -454,11 +456,24 @@ sub node_config {
     return %{$self}{grep exists $self->{$_}, @CONFIG_KEYS};
 }
 
+=head2 configure
+
+Takes the same parameters as L<Net::Async::Redis/configure>, with the addition of:
+
+=over 4
+
+=item * C<use_read_replica> - direct read commands to replicas, instead of the primary nodes
+
+=back
+
+=cut
+
 sub configure {
     my ($self, %args) = @_;
     for (@CONFIG_KEYS) {
         $self->{$_} = delete $args{$_} if exists $args{$_};
     }
+    $self->{read_from_replica} = delete $args{read_from_replica} if exists $args{read_from_replica};
     die 'invalid protocol requested: ' . $self->{protocol} if defined $self->{protocol} and not $self->{protocol} =~ /^resp[23]$/;
 
     die 'hashref support requires RESP3 (Redis version 6+)' if defined $self->{protocol} and $self->{protocol} eq 'resp2' and $self->{hashrefs};
@@ -667,7 +682,13 @@ sub execute_command {
 
 async sub find_node_and_execute_command ($self, @cmd) {
     my $node = await $self->find_node(@cmd);
-    my $redis = await $node->primary_connection;
+    my $redis = await (
+           $self->{read_from_replica}
+        && $node->replica_count
+        && Net::Async::Redis->extract_spec_for_command(\@cmd)->{acl_cat}{'@read'}
+        ? $node->replica_connection
+        : $node->primary_connection
+    );
 
     # Some commands have modifiers around them for RESP2/3 transparent support
     my ($command, @args) = @cmd;
